/**************************************************************************************************|
|* Copyright 2021 Hycon Technology, Corp.                                                         *|
|* http://www.hycontek.com/                                                                       *|
|* Description:                                                                                   *|
|*                                                                                                *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Includes                                                                                      *|
|**************************************************************************************************/
#include <hy17m26sfr.h>
#include <RST.h>
#include <CLK.h>
#include <GPIO.h>
/**************************************************************************************************|
|*  Static Function                                                                               *|
|**************************************************************************************************/

/**************************************************************************************************|
|*  Generic Peripheral Library                                                                    *|
|**************************************************************************************************/

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_GPIO_OpenXTInput                                                                      |
|                                                                                                  |
|  Parameters:                                                                                     |
|         None                                                                                     |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the XT mode for Pin setting                                |
|-------------------------------------------------------------------------------------------------*/
void CLK_GPIO_OpenXTInput(void)
{
    TRISC1 &= (~(TC11_MSK | TC12_MSK));  // config PT1.1/PT1.2 as Input Mode
    PT1PU &= (~(PU11_MSK | PU12_MSK));     // Disable Input pull up in case of Input Mode
}

/*-------------------------------------------------------------------------------------------------|
|  Function: CLK_CPUCKOpen                                                                         |
|                                                                                                  |
|  Parameters:     
|         haom -    [in] HAOM_17510KHZ	/HAOM_8755KHZ  /HAOM_4147KHZ	/HAOM_1843KHZ              |
|         oscs  - [in] OSCS_HAO  / OSCS_LPO	/	OSCS_XT                    						            |
|         dhsck   - [in] DHS_HSCKDIV8	/	DHS_HSCKDIV4									  	 	 			|
|                              DHS_HSCKDIV2	/	DHS_HSCKDIV1                                                        |
|         cpuck  - [in] CPUS_DHSCK / CPUS_HSCK                               |
|                                                                                                  |
|  Returns:                                                                                        |
|         None                                                                                     |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to open the CPU clock setting          
|  Modify date: 2019/07/19                                                             |
|-------------------------------------------------------------------------------------------------*/
void CLK_CPUCKOpen(unsigned char haom,				//HAO Frequence Selection
                                       unsigned char oscs,       		   //HS_CK Selection 
                                       unsigned char dhsck,			     //DHS_CK Selection                                          
                                       unsigned char cpuck)               //CPU_CK Source Selection 
{
    CLK_HAOSelect(haom);         
    CLK_HAOEnable();                
    CLK_OSCSelect(oscs) ;        
    CLK_DHSCKSelect(dhsck);      
    CLK_CPUCKSelect(cpuck);     

}

/*-------------------------------------------------------------------------------------------------|
|  Function: HAO_TrimMode1                                                                         |
|                                                                                                  |
|  Parameters:     
|         trimcnt: 0x3FF~0x00                                                                             |
|  Returns:                                                                                        |
|         1: success                                                                                     |
|         2: fail                                                                                    |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to trim HAO via PT3.1(UART RC pin)      
|                                                                                                  |
|  Modify date: 2021/04/27                                                             |
|-------------------------------------------------------------------------------------------------*/
unsigned char HAO_TrimMode1(unsigned int trimcnt)   //TRIMCNT[9:0] Value
{
    unsigned int result= 0;
   
	GPIO_PT3InputMode(PT31);
    GPIO_PT3DigitalEnable(PT31); 
    TRIMCNTH= trimcnt>> 8;
    TRIMCNTL= 0x00ff & trimcnt;
    HAO_TrimPinSelect(SRC_PT31);
    while(GPIO_PT3GET(PT31)!=0);
    HAO_TrimModeSelect(TRIMEN1_Enable);
    while(result== 0)
    {
        if(HAO_TrimMode1_Read()==0)
        {
            CSFON_Enable();
            CSFCN0= TRIMVAL;        
            result= 1;       //success
        }
        if(HAO_TrimCounter_Read()!=0)
        {
            result= 2;       //fail
        }
    } 
    return result;
}

/*-------------------------------------------------------------------------------------------------|
|  Function: HAO_TrimMode2                                                                      |
|                                                                                                  |
|  Parameters:     
|         trimcnt: 0x3FF~0x00                                                                             |
|  Returns:                                                                                        |
|         1: success                                                                                     |
|         2: fail                                                                                    |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to trim HAO via PT3.0~PT3.7            
|                                                                                                  |
|  Modify date: 2021/04/27                                                             |
|-------------------------------------------------------------------------------------------------*/
unsigned char HAO_TrimMode2(unsigned int trimcnt,   //TRIMCNT[9:0] Value
                            unsigned int trimIO)   //Input Pin Selection
{
    unsigned int Offset= 4,result= 0;
   
	GPIO_PT3InputMode(trimIO);
    GPIO_PT3DigitalEnable(trimIO); 
    TRIMCNTH= trimcnt>> 8;
    TRIMCNTL= 0x00ff & trimcnt;
    HAO_TrimPinSelect(trimIO);
    TRIMCNTH= ((TRIMCNTH & 0x1f)| Offset<< 4);
    while(GPIO_PT3GET(trimIO)!=0);
    HAO_TrimModeSelect(TRIMEN2_Enable);      
    while(result== 0)
    {
        if(HAO_TrimValue_Read()!=0)
        {
            HAO_TrimModeSelect(TRIMEN2_Disable);
            CSFON_Enable();
            CSFCN0= TRIMVAL;
            result= 1;       //success
        }
        if(HAO_TrimCounter_Read()!=0)
        {
            result= 2;       //fail
        }
    }
    return result;
}

/*-------------------------------------------------------------------------------------------------|
|  Function: HAO_TrimMode3                                                                     |
|                                                                                                  |
|  Parameters:     
|         trimcnt: 0x3FF~0x00                                                                             |
|  Returns:                                                                                        |
|         1: success                                                                                     |
|         2: fail                                                                                    |
|                                                                                                  |
|  Description:                                                                                    |
|         This function is used to trim HAO via PT1.1(XTI)            
|                                                                                                  |
|  Modify date: 2021/04/27                                                             |
|-------------------------------------------------------------------------------------------------*/
unsigned char HAO_TrimMode3(unsigned int trimcnt)   //TRIMCNT[9:0] Value
{
    unsigned int Offset= 4,result= 0;
   
    TRIMCNTH= trimcnt>> 8;
    TRIMCNTL= 0x00ff & trimcnt;
    TRIMCNTH= ((TRIMCNTH & 0x1f)| Offset<< 4);
    CLK_XTEnable();
    CLK_XTSelect(XTS_16M);
    HAO_TrimModeSelect(TRIMEN3_Enable);   
    while(result== 0)
    {
        if(HAO_TrimValue_Read()!=0)
        {
            CSFON_Enable();
            CSFCN0= TRIMVAL;
            result= 1;       //success
        }
        if(HAO_TrimCounter_Read()!=0)
        {
            result= 2;       //fail
        }
    }   
    OSCCN2 &= 0xC7;  //ENXT=0b, XTS=00b
    return result;
}
/**************************************************************************************************|
|*  Static Functions                                                                              *|
|**************************************************************************************************/
